%if 0%{?el7}
%define dist .el7
%endif

%global evtlog_ver 0.2.13
%global ivykis_ver 0.42.2

%define vimdir 81

Packager:       momo-i <webmaster@momo-i.org>
Vendor:         momo-i, http://www.momo-i.org/

Name: syslog-ng
Version: 3.16.1
Release: 1%{?dist}
Summary: Next-generation syslog server

Group: System Environment/Daemons
License: GPLv2+
URL: http://syslog-ng.org
Source0: https://github.com/balabit/syslog-ng/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Source1: syslog-ng.conf
Source2: syslog-ng.logrotate
Source3: syslog-ng.service

BuildRequires: perl-generators
BuildRequires: systemd-units
BuildRequires: pkgconfig
BuildRequires: libtool
BuildRequires: bison, flex
BuildRequires: libxslt
BuildRequires: eventlog-devel >= %{evtlog_ver}
BuildRequires: glib2-devel >= 2.10.1
BuildRequires: ivykis-devel >= %{ivykis_ver}
BuildRequires: json-c-devel
BuildRequires: libcap-devel
BuildRequires: libdbi-devel
BuildRequires: libnet-devel
BuildRequires: openssl-devel
BuildRequires: pcre-devel >= 6.1
BuildRequires: libuuid-devel
BuildRequires: libesmtp-devel
BuildRequires: mongo-c-driver-devel
BuildRequires: cyrus-sasl-devel cyrus-sasl-lib
BuildRequires: GeoIP-devel
BuildRequires: systemd-devel
BuildRequires: hiredis-devel
BuildRequires: riemann-c-client-devel
BuildRequires: java-devel
BuildRequires: libcurl-devel
BuildRequires: snappy-devel
BuildRequires: libmaxminddb-devel

# Test suite
%if 0%{?fedora} >= 28
BuildRequires: python2
BuildRequires: python2-unittest2
BuildRequires: python2-nose
BuildRequires: python2-ply
BuildRequires: python2-pep8
BuildRequires: pylint
BuildRequires: python2-six
%else
BuildRequires: python
BuildRequires: python-unittest2
BuildRequires: python-nose
BuildRequires: python-ply
BuildRequires: python-pep8
BuildRequires: pylint
BuildRequires: python-six
%endif
# Test suite: the SQL tests
BuildRequires: libdbi-dbd-sqlite

Requires: logrotate
Requires: ivykis >= %{ivykis_ver}
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

Provides: syslog
# merge separate syslog-vim package into one
Provides: syslog-ng-vim = %{version}-%{release}
Obsoletes: syslog-ng-vim < 2.0.8-1

# Fedora 17 unified filesystem (/usr-move)
Conflicts: filesystem < 3

Obsoletes: syslog-ng-json

%description
syslog-ng is an enhanced log daemon, supporting a wide range of input and
output methods: syslog, unstructured text, message queues, databases (SQL
and NoSQL alike) and more.

Key features:

 * receive and send RFC3164 and RFC5424 style syslog messages
 * work with any kind of unstructured data
 * receive and send JSON formatted messages
 * classify and structure logs with builtin parsers (csv-parser(),
   db-parser(), ...)
 * normalize, crunch and process logs as they flow through the system
 * hand on messages for further processing using message queues (like
   AMQP), files or databases (like PostgreSQL or MongoDB).


%package libdbi
Summary: libdbi support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description libdbi
This module supports a large number of database systems via libdbi.


%package mongodb
Summary: mongodb support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description mongodb
This module supports the mongodb database via libmongo-client.


%package smtp
Summary: smtp support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description smtp
This module supports sending e-mail alerts through an smtp server.

%package java
Summary:        Java destination support for syslog-ng
Group:          System/Libraries
Requires:       %{name} = %{version}

%description java
This package provides java destination support for syslog-ng.

%package geoip
Summary: geoip support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description geoip
This template function returns the 2-letter country code of
any IPv4 address or host.


%package redis
Summary: redis support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description redis
This module supports the redis key-value store via hiredis.

%package riemann
Summary: riemann support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description riemann
This module supports the riemann monitoring server.

%package http
Summary: http support for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}
Obsoletes: %{name}-curl < 3.10

%description http
This module supports the http destination.

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q

# Remove bundled libraries
rm -rf lib/ivykis
rm -rf modules/afamqp/rabbitmq-c
rm -rf modules/afmongodb/mongo-c-driver

# fix perl path
%{__sed} -i 's|^#!/usr/local/bin/perl|#!%{__perl}|' contrib/relogger.pl

# fix executable perms on contrib files
%{__chmod} -c a-x contrib/syslog2ng

# fix authors file
/usr/bin/iconv -f iso8859-1 -t utf-8 AUTHORS > AUTHORS.conv && \
    %{__mv} -f AUTHORS.conv AUTHORS


%build
GEOIP_LIBS=-lGeoIP; export GEOIP_LIBS; \
%configure \
    --prefix=%{_prefix} \
    --sysconfdir=%{_sysconfdir}/%{name} \
    --localstatedir=%{_sharedstatedir}/%{name} \
    --datadir=%{_datadir} \
    --with-module-dir=/%{_libdir}/%{name} \
    --with-systemdsystemunitdir=%{_unitdir} \
    --with-ivykis=system \
    --with-mongoc=system \
    --with-embedded-crypto \
    --enable-manpages \
    --enable-ipv6 \
    --enable-spoof-source \
    --with-linux-caps=auto \
    --enable-sql \
    --enable-json \
    --enable-ssl \
    --enable-smtp \
    --enable-geoip \
    --enable-shared \
    --disable-static \
    --enable-dynamic-linking \
    --enable-systemd \
    --enable-redis \
    --disable-amqp \
    --with-librabbitmq-client=no \
    --disable-python \
    --enable-java \
    --disable-java-modules \
    --enable-riemann


# remove rpath
#sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
#sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{_smp_mflags}


%install
make DESTDIR=%{buildroot} install

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/%{name}/conf.d
%{__install} -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}/syslog-ng.conf

%{__install} -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/syslog

%if 0%{?fedora} || 0%{?rhel} >= 7
%{__install} -d -m 755 %{buildroot}%{_prefix}/lib/systemd/system
%{__install} -p -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}.service
%endif

# create the local state dir
%{__install} -d -m 755 %{buildroot}/%{_sharedstatedir}/%{name}

# install the main library header files
%{__install} -d -m 755 %{buildroot}%{_includedir}/%{name}
%{__install} -p -m 644 config.h %{buildroot}%{_includedir}/%{name}
%{__install} -p -m 644 lib/*.h %{buildroot}%{_includedir}/%{name}

# install vim files
%{__install} -d -m 755 %{buildroot}%{_datadir}/%{name}
%{__install} -p -m 644 contrib/syslog-ng.vim %{buildroot}%{_datadir}/%{name}
for vimver in %{vimdir} ; do
    %{__install} -d -m 755 %{buildroot}%{_datadir}/vim/vim$vimver/syntax
    cd %{buildroot}%{_datadir}/vim/vim$vimver/syntax
    ln -s ../../../%{name}/syslog-ng.vim .
    cd -
done

find %{buildroot} -name "*.la" -exec rm -f {} \;

# remove some extra testing related files
#rm %%{buildroot}/%%{_libdir}/pkgconfig/syslog-ng-test.pc
#rm %%{buildroot}/%%{_libdir}/syslog-ng/libtest/libsyslog-ng-test.a

rm %{buildroot}%{_unitdir}/%{name}@.service

%check
#LD_LIBRARY_PATH=%{buildroot}/%{_libdir}:%{buildroot}/%{_libdir}/%{name} VERBOSE=1 make check


%post
ldconfig
%systemd_post syslog-ng.service

%preun
%systemd_preun syslog-ng.service

%postun
ldconfig
%systemd_postun_with_restart syslog-ng.service


%triggerun -- syslog-ng < 3.2.3
if /sbin/chkconfig --level 3 %{name} ; then
    /bin/systemctl enable %{name}.service >/dev/null 2>&1 || :
fi


%triggerin -- vim-common
VIMVERNEW=`rpm -q --qf='%%{epoch}:%%{version}\n' vim-common | sort | tail -n 1 | sed -e 's/[0-9]*://' | sed -e 's/\.[0-9]*$//' | sed -e 's/\.//'`
[ -d %{_datadir}/vim/vim${VIMVERNEW}/syntax ] && \
    cd %{_datadir}/vim/vim${VIMVERNEW}/syntax && \
    ln -sf ../../../%{name}/syslog-ng.vim . || :

%triggerun -- vim-common
VIMVEROLD=`rpm -q --qf='%%{epoch}:%%{version}\n' vim-common | sort | head -n 1 | sed -e 's/[0-9]*://' | sed -e 's/\.[0-9]*$//' | sed -e 's/\.//'`
[ $2 = 0 ] && rm -f %{_datadir}/vim/vim${VIMVEROLD}/syntax/syslog-ng.vim || :

%triggerpostun -- vim-common
VIMVEROLD=`rpm -q --qf='%%{epoch}:%%{version}\n' vim-common | sort | head -n 1 | sed -e 's/[0-9]*://' | sed -e 's/\.[0-9]*$//' | sed -e 's/\.//'`
VIMVERNEW=`rpm -q --qf='%%{epoch}:%%{version}\n' vim-common | sort | tail -n 1 | sed -e 's/[0-9]*://' | sed -e 's/\.[0-9]*$//' | sed -e 's/\.//'`
if [ $1 = 1 ]; then
    rm -f %{_datadir}/vim/vim${VIMVEROLD}/syntax/syslog-ng.vim || :
    [ -d %{_datadir}/vim/vim${VIMVERNEW}/syntax ] && \
        cd %{_datadir}/vim/vim${VIMVERNEW}/syntax && \
        ln -sf ../../../%{name}/syslog-ng.vim . || :
fi


%files
%doc AUTHORS NEWS.md
%doc contrib/{relogger.pl,syslog2ng,syslog-ng.conf.doc}
%{!?_licensedir:%global license %%doc}
%license COPYING

%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/conf.d
%dir %{_sysconfdir}/%{name}/patterndb.d
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/scl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/syslog
%{_unitdir}/%{name}.service

%dir %{_sharedstatedir}/%{name}
%{_sbindir}/%{name}
%{_sbindir}/%{name}-debun
%{_sbindir}/syslog-ng-ctl
%{_bindir}/loggen
%{_bindir}/pdbtool
%{_bindir}/update-patterndb
%{_bindir}/dqtool
%{_libdir}/lib%{name}-*.so.*
%{_libdir}/libevtlog-*.so.*
%{_libdir}/libsecret-storage.so.*
%{_libdir}/libloggen_helper-*.so.*
%{_libdir}/libloggen_plugin-*.so.*
%{_libdir}/%{name}/*.so
%{_libdir}/%{name}/loggen/*.so
%exclude %{_libdir}/%{name}/libafsql.so
%exclude %{_libdir}/%{name}/libafmongodb.so
%exclude %{_libdir}/%{name}/libredis.so
%exclude %{_libdir}/%{name}/libafsmtp.so
%exclude %{_libdir}/%{name}/libriemann.so
%exclude %{_libdir}/%{name}/libgeoip-plugin.so
%exclude %{_libdir}/%{name}/libgeoip2-plugin.so
%exclude %{_libdir}/%{name}/libhttp.so
%exclude %{_libdir}/%{name}/libmod-java.so

%dir %{_datadir}/%{name}
%{_datadir}/%{name}/syslog-ng.vim
%ghost %{_datadir}/vim/

# scl files
%{_datadir}/%{name}/include/

# uhm, some better places for those?
%{_datadir}/%{name}/xsd/

%{_mandir}/man1/loggen.1*
%{_mandir}/man1/pdbtool.1*
%{_mandir}/man1/syslog-ng-ctl.1*
%{_mandir}/man1/syslog-ng-debun.1*
%{_mandir}/man1/dqtool.1*
%{_mandir}/man5/syslog-ng.conf.5*
%{_mandir}/man8/syslog-ng.8*

%files libdbi
%{_libdir}/%{name}/libafsql.so

%files mongodb
%{_libdir}/%{name}/libafmongodb.so

%files redis
%{_libdir}/%{name}/libredis.so

%files smtp
%{_libdir}/%{name}/libafsmtp.so

%files java
%attr(755,root,root) %{_libdir}/syslog-ng/libmod-java.so
%dir %{_libdir}/%{name}/java-modules/
%{_libdir}/%{name}/java-modules/*

%files geoip
%{_libdir}/%{name}/libgeoip-plugin.so
%{_libdir}/%{name}/libgeoip2-plugin.so

%files riemann
%{_libdir}/%{name}/libriemann.so

%files http
%{_libdir}/%{name}/libhttp.so

%files devel
%{_libdir}/libsyslog-ng.so
%{_libdir}/libsyslog-ng-native-connector.a
%{_libdir}/libevtlog.so
%{_libdir}/libsecret-storage.so
%{_libdir}/libloggen_helper.so
%{_libdir}/libloggen_plugin.so
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/syslog-ng.pc
%{_libdir}/pkgconfig/syslog-ng-native-connector.pc
%{_datadir}/%{name}/tools/

%changelog
* Sun Jul 15 2018 momo-i <webmaster@momo-i.org> - 3.16.1-1
- Update to 3.16.1

* Thu Nov 23 2017 momo-i <webmaster@momo-i.org> - 3.12.1-1
- Update to 3.12.1

* Wed Feb 08 2017 momo-i <webmaster@momo-i.org> - 3.9.1-1
- Update to 3.9.1

* Fri Dec 30 2016 momo-i <webmaster@momo-i.org> - 3.8.1-3
- Merge from fedora repo

* Sun Dec 25 2016 momo-i <webmaster@momo-i.org> - 3.8.1-2
- Update vim version

* Sat Aug 27 2016 momo-i <webmaster@momo-i.org> - 3.8.1-1
- Update to 3.8.1

* Mon Mar 28 2016 momo-i <webmaster@momo-i.org> - 3.7.3-1
- Update to 3.7.3

* Mon Nov 09 2015 momo-i <webmaster@momo-i.org> - 3.7.2-1
- Update to 3.7.2

* Mon Sep 07 2015 momo-i <webmaster@momo-i.org> - 3.7.1-2
- Update syslog-ng.conf

* Mon Sep 07 2015 momo-i <webmaster@momo-i.org> - 3.7.1-1
- Update to 3.7.1

* Thu Sep 03 2015 momo-i <webmaster@momo-i.org> - 3.6.4-7
- Update dist for centos7

* Mon Aug 10 2015 momo-i <webmaster@momo-i.org> - 3.6.4-6
- Rebuilt for fc23

* Fri Jun 26 2015 momo-i <webmaster@momo-i.org> - 3.6.4-5
- Update to 3.6.4

* Thu Apr 16 2015 momo-i <webmaster@momo-i.org> - 3.6.2-5
- Rebuilt for fc22

* Fri Mar 20 2015 momo-i <webmaster@momo-i.org> - 3.6.2-4
- Update to 3.6.2
- Update vim ver
- systemd-journal: Fix the failing test cases
  https://github.com/algernon/syslog-ng/commit/ed0976f87ddf7f9986e22a0b64dc3aef9249046a

